@@ -21,7 +21,7 @@
 #define OGRE_BUILD_COMPONENT_PROPERTY
 #define OGRE_BUILD_COMPONENT_OVERLAY
 #define OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
-#define OGRE_BUILD_COMPONENT_HLMS
+/* #undef OGRE_BUILD_COMPONENT_HLMS */
 
 #define OGRE_BITES_HAVE_SDL 0
 
