@@ -31,31 +31,11 @@ THE SOFTWARE.
 #include "OgreGLPrerequisites.h"
 #include "OgreGLSLShaderCommon.h"
 #include "OgreRenderOperation.h"
+#include "OgreGLGpuProgram.h"
 
 namespace Ogre {
     namespace GLSL {
-    /** Specialisation of HighLevelGpuProgram to provide support for OpenGL
-        Shader Language (GLSL).
-    @remarks
-        GLSL has no target assembler or entry point specification like DirectX 9 HLSL.
-        Vertex and Fragment shaders only have one entry point called "main".  
-        When a shader is compiled, microcode is generated but can not be accessed by
-        the application.
-        GLSL also does not provide assembler low level output after compiling.  The GL Render
-        system assumes that the Gpu program is a GL Gpu program so GLSLProgram will create a 
-        GLSLGpuProgram that is subclassed from GLGpuProgram for the low level implementation.
-        The GLSLProgram class will create a shader object and compile the source but will
-        not create a program object.  It's up to GLSLGpuProgram class to request a program object
-        to link the shader object to.
-
-    @note
-        GLSL supports multiple modular shader objects that can be attached to one program
-        object to form a single shader.  This is supported through the "attach" material script
-        command.  All the modules to be attached are listed on the same line as the attach command
-        separated by white space.
-        
-    */
-    class _OgreGLExport GLSLProgram : public GLSLShaderCommon
+    class _OgreGLExport GLSLProgram : public GLSLShaderCommon, public GLGpuProgramBase
     {
     public:
         GLSLProgram(ResourceManager* creator, 
@@ -63,7 +43,6 @@ namespace Ogre {
             const String& group, bool isManual, ManualResourceLoader* loader);
         ~GLSLProgram();
 
-        GLhandleARB getGLHandle() const { return mGLHandle; }
         void attachToProgramObject( const GLhandleARB programObject );
         void detachFromProgramObject( const GLhandleARB programObject );
 
@@ -80,9 +59,6 @@ namespace Ogre {
             return true;
         }
 
-        /// compile source into shader object
-        bool compile( bool checkErrors = true);
-
         /** Returns the operation type that this geometry program expects to
             receive as input
         */
@@ -125,13 +101,12 @@ namespace Ogre {
         void setMaxOutputVertices(int maxOutputVertices)
         { mMaxOutputVertices = maxOutputVertices; }
 
+        void bindProgram();
+        void unbindProgram();
+        void bindProgramParameters(GpuProgramParametersSharedPtr params, uint16 mask);
+        bool isAttributeValid(VertexElementSemantic semantic, uint index);
     protected:
-        /** Internal method for creating a dummy low-level program for this
-        high-level program. GLSL does not give access to the low level implementation of the
-        shader so this method creates an object sub-classed from GLGpuProgram just to be
-        compatible with GLRenderSystem.
-        */
-        void createLowLevelImpl(void);
+        void loadFromSource();
         /// Internal unload implementation, must be implemented by subclasses
         void unloadHighLevelImpl(void);
 
@@ -144,10 +119,6 @@ namespace Ogre {
         RenderOperation::OperationType mInputOperationType;
         RenderOperation::OperationType mOutputOperationType;
         int mMaxOutputVertices;
-
-    private:
-        /// GL handle for shader object
-        GLhandleARB mGLHandle;
     };
     }
 }
